# universions

Python library to get the version of other tools

[![PyPI pyversions](https://img.shields.io/pypi/pyversions/universions.svg)](https://pypi.python.org/pypi/universions/)  
[![PyPI version](https://badge.fury.io/py/universions.svg)](https://badge.fury.io/py/universions)  
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)

## Install

### with pip

```bash
pip install universions
```

## Languages and other tools supported

universions does not support anything at the moment.

Java and node coming soon.

Open an issue if you want more !
